@@ -787,6 +787,7 @@ class LkeClient(AbstractClient):
 
     def GetEmbedding(self, request):
         """获取特征向量
+        本接口有单账号调用上限控制，如您有提高并发限制的需求请 [联系我们](https://cloud.tencent.com/act/event/Online_service) 。
 
         :param request: Request instance for GetEmbedding.
         :type request: :class:`tencentcloud.lke.v20231130.models.GetEmbeddingRequest`
@@ -1476,7 +1477,7 @@ class LkeClient(AbstractClient):
 
 
     def ParseDoc(self, request):
-        """解析拆分文件
+        """解析拆分文档。该接口需开通文档解析原子能力后调用。文档解析原子能力内测中，如有需要请联系架构师或 [联系客服](https://cloud.tencent.com/act/event/Online_service)  。
 
         :param request: Request instance for ParseDoc.
         :type request: :class:`tencentcloud.lke.v20231130.models.ParseDocRequest`
@@ -1499,7 +1500,7 @@ class LkeClient(AbstractClient):
 
 
     def QueryParseDocResult(self, request):
-        """查询文件解析结果
+        """查询文档解析结果。该接口需开通文档解析原子能力后调用。文档解析原子能力内测中，如有需要请联系架构师或[联系客服](https://cloud.tencent.com/act/event/Online_service) 。
 
         :param request: Request instance for QueryParseDocResult.
         :type request: :class:`tencentcloud.lke.v20231130.models.QueryParseDocResultRequest`
@@ -1523,6 +1524,7 @@ class LkeClient(AbstractClient):
 
     def QueryRewrite(self, request):
         """多轮改写
+        本接口有单账号调用上限控制，如您有提高并发限制的需求请 [联系我们](https://cloud.tencent.com/act/event/Online_service) 。
 
         :param request: Request instance for QueryRewrite.
         :type request: :class:`tencentcloud.lke.v20231130.models.QueryRewriteRequest`
